@@ -5,11 +5,13 @@ test_get_requests:
 A module intended for use with Nose.
 
 """
+import copy
 
 import requests
-import copy
-import json
 import six
+from nose.plugins.attrib import attr
+from requests.compat import json as _json
+
 
 default_headers = {'plotly-username': '',
                    'plotly-apikey': '',
@@ -23,6 +25,7 @@ server = "https://plot.ly"
 # api_key = "vgs6e0cnoi" (currently...)
 
 
+@attr('slow')
 def test_user_does_not_exist():
     username = 'user_does_not_exist'
     api_key = 'invalid-apikey'
@@ -34,9 +37,9 @@ def test_user_does_not_exist():
     resource = "/apigetfile/{0}/{1}/".format(file_owner, file_id)
     response = requests.get(server + resource, headers=hd)
     if six.PY3:
-        content = json.loads(response.content.decode('unicode_escape'))
+        content = _json.loads(response.content.decode('unicode_escape'))
     else:
-        content = json.loads(response.content)
+        content = _json.loads(response.content)
     print(response.status_code)
     print(content)
     assert response.status_code == 404
@@ -45,6 +48,7 @@ def test_user_does_not_exist():
                                 "sensitive.".format(username))
 
 
+@attr('slow')
 def test_file_does_not_exist():
     username = 'PlotlyImageTest'
     api_key = '786r5mecv0'
@@ -56,9 +60,9 @@ def test_file_does_not_exist():
     resource = "/apigetfile/{0}/{1}/".format(file_owner, file_id)
     response = requests.get(server + resource, headers=hd)
     if six.PY3:
-        content = json.loads(response.content.decode('unicode_escape'))
+        content = _json.loads(response.content.decode('unicode_escape'))
     else:
-        content = json.loads(response.content)
+        content = _json.loads(response.content)
     print(response.status_code)
     print(content)
     assert response.status_code == 404
@@ -66,6 +70,7 @@ def test_file_does_not_exist():
                                 "exist. Want to try again?")
 
 
+@attr('slow')
 def test_wrong_api_key():  # TODO: does this test the right thing?
     username = 'PlotlyImageTest'
     api_key = 'invalid-apikey'
@@ -83,6 +88,7 @@ def test_wrong_api_key():  # TODO: does this test the right thing?
 # Locked File
 # TODO
 
+@attr('slow')
 def test_private_permission_defined():
     username = 'PlotlyImageTest'
     api_key = '786r5mecv0'
@@ -94,9 +100,9 @@ def test_private_permission_defined():
     resource = "/apigetfile/{0}/{1}/".format(file_owner, file_id)
     response = requests.get(server + resource, headers=hd)
     if six.PY3:
-        content = json.loads(response.content.decode('unicode_escape'))
+        content = _json.loads(response.content.decode('unicode_escape'))
     else:
-        content = json.loads(response.content)
+        content = _json.loads(response.content)
     print(response.status_code)
     print(content)
     assert response.status_code == 403
@@ -105,6 +111,7 @@ def test_private_permission_defined():
 # TODO
 
 
+@attr('slow')
 def test_missing_headers():
     file_owner = 'get_test_user'
     file_id = 0
@@ -115,14 +122,15 @@ def test_missing_headers():
         del hd[header]
         response = requests.get(server + resource, headers=hd)
         if six.PY3:
-            content = json.loads(response.content.decode('unicode_escape'))
+            content = _json.loads(response.content.decode('unicode_escape'))
         else:
-            content = json.loads(response.content)
+            content = _json.loads(response.content)
         print(response.status_code)
         print(content)
         assert response.status_code == 422
 
 
+@attr('slow')
 def test_valid_request():
     username = 'PlotlyImageTest'
     api_key = '786r5mecv0'
@@ -134,16 +142,15 @@ def test_valid_request():
     resource = "/apigetfile/{0}/{1}/".format(file_owner, file_id)
     response = requests.get(server + resource, headers=hd)
     if six.PY3:
-        content = json.loads(response.content.decode('unicode_escape'))
+        content = _json.loads(response.content.decode('unicode_escape'))
     else:
-        content = json.loads(response.content)
+        content = _json.loads(response.content)
     print(response.status_code)
     print(content)
     assert response.status_code == 200
-    # content = json.loads(res.content)
+    # content = _json.loads(res.content)
     # response_payload = content['payload']
     # figure = response_payload['figure']
     # if figure['data'][0]['x'] != [u'1', u'2', u'3']:
     #     print('ERROR')
     # return res
-
